@@ -61,11 +61,11 @@ def query_cache(cache_key, conn_name=options.cache_conn):
 
 
 def format_insert_key(signature, func_name, args, params):
-    _args = args
+    _args = copy.deepcopy(args)
     param_keys = list(signature.parameters.keys())
     if param_keys and args:
         if param_keys[0] == "self":
-            _args = args[1:]
+            _args = copy.deepcopy(args[1:])
     if isinstance(_args, tuple):
         _args = list(_args)
     for k in params:
